# Хаб

Добро пожаловать в документацию AliceIO!

Начинающим рекомендуется ознакомиться с [туториалом](tutorial/index.md).
Знание Python'а приветствуется и рекомендуется.

> Проект написан с использованием исходного кода [aiogram](https://github.com/aiogram/aiogram/){:target="_blank"},
> [vkbottle](https://github.com/vkbottle/vkbottle/){:target="_blank"}
> и [aioalice](https://github.com/mahenzon/aioalice){:target="_blank"}
>
> Спасибо авторам и участникам этих замечательных библиотек
